@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es_ES">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_ES">
 <context>
     <name>MainWindow</name>
     <message>
@@ -251,10 +249,6 @@
         <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
         <translation>Las fuentes APT originales se han restaurado al estado de liberacion. Los archivos de fuentes añadidos por el usuario en /etc/apt/sources.list.d/ no se han tocado.</translation>
     </message>
-    <message>
-        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
-        <translation type="vanished">Hubo un error al escribir el archivo: %1. Por favor, compruebe si tiene suficiente espacio libre en su disco</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -296,4 +290,4 @@
         <translation>Debe ejecutar este programa con acceso de administrador.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
